@@ -1,7 +1,6 @@
 #
 # Testing functions for a mapsequence solar derotation functionality.
 #
-import os
 from copy import deepcopy
 
 import numpy as np
@@ -12,7 +11,6 @@ import astropy.units as u
 from astropy.coordinates import SkyCoord
 from astropy.tests.helper import assert_quantity_allclose
 
-import sunpy.data.test
 import sunpy.map
 from sunpy.physics.solar_rotation import calculate_solar_rotate_shift, mapsequence_solar_derotate
 
@@ -20,12 +18,6 @@ DEP_WARNING = r'''ignore:The {} function is deprecated and may be removed in ver
 \s+Use `sunkit_image.coalignment.{}` instead.:sunpy.util.exceptions.SunpyDeprecationWarning'''
 
 
-@pytest.fixture
-def aia171_test_map():
-    testpath = sunpy.data.test.rootdir
-    return sunpy.map.Map(os.path.join(testpath, 'aia_171_level1.fits'))
-
-
 @pytest.fixture
 def aia171_test_submap(aia171_test_map):
     return aia171_test_map.submap(SkyCoord(((0, 0), (400, 500))*u.arcsec,
