@@ -228,7 +228,8 @@ def test_parse_time_ISO():
         ('04-May-2007', dt5),
         ('04-May-2007 21:08:12.999999', dt2),
         ('20070504_210812', dt3),
-        ('2007/05/04T21:08', dt4),
+        ('2007.05.04_21:08:12_UTC', dt3),
+        ('2007.05.04_21:08:12', dt3),
     ]
 
     for k, v in lst:
